# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageFeaturePython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkUnsharpMaskImageFilterPython
else:
    import _itkUnsharpMaskImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.itkRGBPixelPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython

def itkUnsharpMaskImageFilterIF2IF2_New():
    return itkUnsharpMaskImageFilterIF2IF2.New()

class itkUnsharpMaskImageFilterIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkUnsharpMaskImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkUnsharpMaskImageFilterIF2IF2_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkUnsharpMaskImageFilterIF2IF2_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_Clone(self)
    SameDimensionCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_SameDimensionCheck
    
    InputHasNumericTraitsCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_InputHasNumericTraitsCheck
    
    InternalTypeIsFloatingPoint = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_InternalTypeIsFloatingPoint
    

    def SetSigmas(self, _arg):
        r"""
        SetSigmas(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_SetSigmas(self, _arg)

    def GetSigmas(self):
        r"""GetSigmas(self) -> itkFixedArrayD2"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_GetSigmas(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double const

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_SetSigma(self, sigma)

    def SetAmount(self, _arg):
        r"""
        SetAmount(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_SetAmount(self, _arg)

    def GetAmount(self):
        r"""GetAmount(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_GetAmount(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_GetThreshold(self)

    def SetClamp(self, _arg):
        r"""
        SetClamp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_SetClamp(self, _arg)

    def GetClamp(self):
        r"""GetClamp(self) -> bool"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_GetClamp(self)

    def ClampOn(self):
        r"""ClampOn(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_ClampOn(self)

    def ClampOff(self):
        r"""ClampOff(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_ClampOff(self)
    __swig_destroy__ = _itkUnsharpMaskImageFilterPython.delete_itkUnsharpMaskImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkUnsharpMaskImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkUnsharpMaskImageFilterIF2IF2

        Create a new object of the class itkUnsharpMaskImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkUnsharpMaskImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkUnsharpMaskImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkUnsharpMaskImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkUnsharpMaskImageFilterIF2IF2 in _itkUnsharpMaskImageFilterPython:
_itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF2IF2_swigregister(itkUnsharpMaskImageFilterIF2IF2)

def itkUnsharpMaskImageFilterIF3IF3_New():
    return itkUnsharpMaskImageFilterIF3IF3.New()

class itkUnsharpMaskImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkUnsharpMaskImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkUnsharpMaskImageFilterIF3IF3_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkUnsharpMaskImageFilterIF3IF3_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_Clone(self)
    SameDimensionCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_SameDimensionCheck
    
    InputHasNumericTraitsCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_InputHasNumericTraitsCheck
    
    InternalTypeIsFloatingPoint = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_InternalTypeIsFloatingPoint
    

    def SetSigmas(self, _arg):
        r"""
        SetSigmas(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_SetSigmas(self, _arg)

    def GetSigmas(self):
        r"""GetSigmas(self) -> itkFixedArrayD3"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_GetSigmas(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double const

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_SetSigma(self, sigma)

    def SetAmount(self, _arg):
        r"""
        SetAmount(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_SetAmount(self, _arg)

    def GetAmount(self):
        r"""GetAmount(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_GetAmount(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_GetThreshold(self)

    def SetClamp(self, _arg):
        r"""
        SetClamp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_SetClamp(self, _arg)

    def GetClamp(self):
        r"""GetClamp(self) -> bool"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_GetClamp(self)

    def ClampOn(self):
        r"""ClampOn(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_ClampOn(self)

    def ClampOff(self):
        r"""ClampOff(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_ClampOff(self)
    __swig_destroy__ = _itkUnsharpMaskImageFilterPython.delete_itkUnsharpMaskImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkUnsharpMaskImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkUnsharpMaskImageFilterIF3IF3

        Create a new object of the class itkUnsharpMaskImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkUnsharpMaskImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkUnsharpMaskImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkUnsharpMaskImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkUnsharpMaskImageFilterIF3IF3 in _itkUnsharpMaskImageFilterPython:
_itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIF3IF3_swigregister(itkUnsharpMaskImageFilterIF3IF3)

def itkUnsharpMaskImageFilterISS2ISS2_New():
    return itkUnsharpMaskImageFilterISS2ISS2.New()

class itkUnsharpMaskImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkUnsharpMaskImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkUnsharpMaskImageFilterISS2ISS2_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkUnsharpMaskImageFilterISS2ISS2_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_Clone(self)
    SameDimensionCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_SameDimensionCheck
    
    InputHasNumericTraitsCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_InputHasNumericTraitsCheck
    
    InternalTypeIsFloatingPoint = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_InternalTypeIsFloatingPoint
    

    def SetSigmas(self, _arg):
        r"""
        SetSigmas(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_SetSigmas(self, _arg)

    def GetSigmas(self):
        r"""GetSigmas(self) -> itkFixedArrayD2"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_GetSigmas(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double const

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_SetSigma(self, sigma)

    def SetAmount(self, _arg):
        r"""
        SetAmount(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_SetAmount(self, _arg)

    def GetAmount(self):
        r"""GetAmount(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_GetAmount(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_GetThreshold(self)

    def SetClamp(self, _arg):
        r"""
        SetClamp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_SetClamp(self, _arg)

    def GetClamp(self):
        r"""GetClamp(self) -> bool"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_GetClamp(self)

    def ClampOn(self):
        r"""ClampOn(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_ClampOn(self)

    def ClampOff(self):
        r"""ClampOff(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_ClampOff(self)
    __swig_destroy__ = _itkUnsharpMaskImageFilterPython.delete_itkUnsharpMaskImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkUnsharpMaskImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkUnsharpMaskImageFilterISS2ISS2

        Create a new object of the class itkUnsharpMaskImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkUnsharpMaskImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkUnsharpMaskImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkUnsharpMaskImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkUnsharpMaskImageFilterISS2ISS2 in _itkUnsharpMaskImageFilterPython:
_itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS2ISS2_swigregister(itkUnsharpMaskImageFilterISS2ISS2)

def itkUnsharpMaskImageFilterISS3ISS3_New():
    return itkUnsharpMaskImageFilterISS3ISS3.New()

class itkUnsharpMaskImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkUnsharpMaskImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkUnsharpMaskImageFilterISS3ISS3_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkUnsharpMaskImageFilterISS3ISS3_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_Clone(self)
    SameDimensionCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_SameDimensionCheck
    
    InputHasNumericTraitsCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_InputHasNumericTraitsCheck
    
    InternalTypeIsFloatingPoint = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_InternalTypeIsFloatingPoint
    

    def SetSigmas(self, _arg):
        r"""
        SetSigmas(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_SetSigmas(self, _arg)

    def GetSigmas(self):
        r"""GetSigmas(self) -> itkFixedArrayD3"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_GetSigmas(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double const

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_SetSigma(self, sigma)

    def SetAmount(self, _arg):
        r"""
        SetAmount(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_SetAmount(self, _arg)

    def GetAmount(self):
        r"""GetAmount(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_GetAmount(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_GetThreshold(self)

    def SetClamp(self, _arg):
        r"""
        SetClamp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_SetClamp(self, _arg)

    def GetClamp(self):
        r"""GetClamp(self) -> bool"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_GetClamp(self)

    def ClampOn(self):
        r"""ClampOn(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_ClampOn(self)

    def ClampOff(self):
        r"""ClampOff(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_ClampOff(self)
    __swig_destroy__ = _itkUnsharpMaskImageFilterPython.delete_itkUnsharpMaskImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkUnsharpMaskImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkUnsharpMaskImageFilterISS3ISS3

        Create a new object of the class itkUnsharpMaskImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkUnsharpMaskImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkUnsharpMaskImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkUnsharpMaskImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkUnsharpMaskImageFilterISS3ISS3 in _itkUnsharpMaskImageFilterPython:
_itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterISS3ISS3_swigregister(itkUnsharpMaskImageFilterISS3ISS3)

def itkUnsharpMaskImageFilterIUC2IUC2_New():
    return itkUnsharpMaskImageFilterIUC2IUC2.New()

class itkUnsharpMaskImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkUnsharpMaskImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkUnsharpMaskImageFilterIUC2IUC2_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkUnsharpMaskImageFilterIUC2IUC2_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_Clone(self)
    SameDimensionCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_SameDimensionCheck
    
    InputHasNumericTraitsCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_InputHasNumericTraitsCheck
    
    InternalTypeIsFloatingPoint = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_InternalTypeIsFloatingPoint
    

    def SetSigmas(self, _arg):
        r"""
        SetSigmas(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_SetSigmas(self, _arg)

    def GetSigmas(self):
        r"""GetSigmas(self) -> itkFixedArrayD2"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_GetSigmas(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double const

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_SetSigma(self, sigma)

    def SetAmount(self, _arg):
        r"""
        SetAmount(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_SetAmount(self, _arg)

    def GetAmount(self):
        r"""GetAmount(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_GetAmount(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_GetThreshold(self)

    def SetClamp(self, _arg):
        r"""
        SetClamp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_SetClamp(self, _arg)

    def GetClamp(self):
        r"""GetClamp(self) -> bool"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_GetClamp(self)

    def ClampOn(self):
        r"""ClampOn(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_ClampOn(self)

    def ClampOff(self):
        r"""ClampOff(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_ClampOff(self)
    __swig_destroy__ = _itkUnsharpMaskImageFilterPython.delete_itkUnsharpMaskImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkUnsharpMaskImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkUnsharpMaskImageFilterIUC2IUC2

        Create a new object of the class itkUnsharpMaskImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkUnsharpMaskImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkUnsharpMaskImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkUnsharpMaskImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkUnsharpMaskImageFilterIUC2IUC2 in _itkUnsharpMaskImageFilterPython:
_itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC2IUC2_swigregister(itkUnsharpMaskImageFilterIUC2IUC2)

def itkUnsharpMaskImageFilterIUC3IUC3_New():
    return itkUnsharpMaskImageFilterIUC3IUC3.New()

class itkUnsharpMaskImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkUnsharpMaskImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkUnsharpMaskImageFilterIUC3IUC3_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkUnsharpMaskImageFilterIUC3IUC3_Pointer"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_Clone(self)
    SameDimensionCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_SameDimensionCheck
    
    InputHasNumericTraitsCheck = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_InputHasNumericTraitsCheck
    
    InternalTypeIsFloatingPoint = _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_InternalTypeIsFloatingPoint
    

    def SetSigmas(self, _arg):
        r"""
        SetSigmas(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_SetSigmas(self, _arg)

    def GetSigmas(self):
        r"""GetSigmas(self) -> itkFixedArrayD3"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_GetSigmas(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double const

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_SetSigma(self, sigma)

    def SetAmount(self, _arg):
        r"""
        SetAmount(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_SetAmount(self, _arg)

    def GetAmount(self):
        r"""GetAmount(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_GetAmount(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_GetThreshold(self)

    def SetClamp(self, _arg):
        r"""
        SetClamp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_SetClamp(self, _arg)

    def GetClamp(self):
        r"""GetClamp(self) -> bool"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_GetClamp(self)

    def ClampOn(self):
        r"""ClampOn(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_ClampOn(self)

    def ClampOff(self):
        r"""ClampOff(self)"""
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_ClampOff(self)
    __swig_destroy__ = _itkUnsharpMaskImageFilterPython.delete_itkUnsharpMaskImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkUnsharpMaskImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkUnsharpMaskImageFilterIUC3IUC3

        Create a new object of the class itkUnsharpMaskImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkUnsharpMaskImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkUnsharpMaskImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkUnsharpMaskImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkUnsharpMaskImageFilterIUC3IUC3 in _itkUnsharpMaskImageFilterPython:
_itkUnsharpMaskImageFilterPython.itkUnsharpMaskImageFilterIUC3IUC3_swigregister(itkUnsharpMaskImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def unsharp_mask_image_filter(*args: itkt.ImageLike,  sigmas: Sequence[float]=..., sigma: float=..., amount: float=..., threshold: float=..., clamp: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for UnsharpMaskImageFilter"""
    import itk

    kwarg_typehints = { 'sigmas':sigmas,'sigma':sigma,'amount':amount,'threshold':threshold,'clamp':clamp }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.UnsharpMaskImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def unsharp_mask_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageFeature.UnsharpMaskImageFilter
    unsharp_mask_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    unsharp_mask_image_filter.__doc__ = filter_object.__doc__



